require "common"

sim_control = {
  time_control = {
    max = tEnd,
    interval = tEnd / 10,
  }
}

physics = { dt = dt, rho0 = rhoPhy }

scheme = {
  identify = {
    label = scheme_label,
    kind = kind,
    relaxation = relaxation,
    layout = layout,
  }, -- identify table

  fluid = { omega = omega, rho0 = rhoPhy },

  -- Initial condition for each field
  initial_condition = {
    pressure  = ic_pressure,
    velocityX = ic_velocityX,
    velocityY = ic_velocityY,
    velocityZ = ic_velocityZ,
    Sxx = ic_Sxx,
    Syy = ic_Syy,
    Szz = 0.0,
    Sxy = ic_Sxy,
    Syz = 0.0,
    Sxz = 0.0,
  }, -- intitial condition end

  variable = {
      { name = 'refPressure',  
        ncomponents = 1, 
        vartype = 'st_fun',
        st_fun = pressure },
      { name = 'refVelMag  ',  
        ncomponents = 1, 
        vartype = 'st_fun',
        st_fun = Velocity },
      { name = 'refVelocityX', 
        ncomponents = 1, 
        vartype = 'st_fun',
        st_fun = velocityX },
      { name = 'refVelocityY', 
        ncomponents = 1, 
        vartype = 'st_fun',
        st_fun = velocityY },
      { name = 'refSxx', 
        ncomponents = 1, 
        vartype = 'st_fun',
        st_fun = Sxx },
      { name = 'refSyy', 
        ncomponents = 1,
        vartype = 'st_fun',
        st_fun = Syy },
      { name = 'diff_vel', 
        ncomponents = 1,
        vartype = 'operation',
        operation = {
          kind = 'difference',
          input_varname = { 'refVelMag','vel_mag_phy' }
        }
      },
      { name = 'diff_pressure', 
        ncomponents = 1,
        vartype = 'operation',
        operation = {
          kind = 'difference',
          input_varname = {'refPressure','pressure_phy'}
        }
      },
  },

  tracking = {
    --{ -- probe point
    --  label = 'L'..level..'_'..relaxation..'_probe',
    --  variable = {
    --    'pressure_phy',
    --    'refPressure',
    --    'velocity_phy',
    --    'refVelocityX',
    --    'refVelocityY',
    --    'strainRate_phy',
    --    'refSxx',
    --    'refSyy',
    --  },
    --  folder = 'tracking/',
    --  shape = { kind = 'canoND', object = {origin = xProbe } },
    --  format = 'ascii',
    --  time_control = {min = 0, max = tEnd, interval = dt},
    --},
    { -- strain rate SPATIAL
      label = 'L'..level..'_spatial',
      variable = {
        'strainRate_phy',
        'refSxx',
        'refSyy',
        'pressure_phy',
        'refPressure',
        'velocity_phy',
        'refVelocityX',
        'refVelocityY',
      },
      folder = 'tracking/',
      --shape = { kind = 'all' },
      shape = {
        kind = 'canoND',
        object = {
          origin = refine_origin,
          vec = {
            refine_vec1, refine_vec2,
          },
          segments = { 2^maxLevel, 2^maxLevel },
        },
      }, -- shape
      format = 'asciiSpatial',
      time_control = {
        min = tEnd,
        max = tEnd,
        interval = tEnd,
      },
    },
    { -- vertical line
      label = 'L'..level..'_vertical_line',
      variable = {
        'strainRate_phy',
        'refSxx',
        'refSyy',
        'pressure_phy',
        'refPressure',
        'velocity_phy',
        'refVelocityX',
        'refVelocityY',
      },
      folder = 'tracking/',
      --shape = { kind = 'all' },
      shape = {
        kind = 'canoND',
        object = {
          origin = { length/2 + dxDash, dxDash, dx+dxDash },
          vec = {
            {0.0, length - dxDash, 0.0},
          },
          segments = { 2^maxLevel },
        },
      }, -- shape
      format = 'asciiSpatial',
      time_control = {
        min = tEnd,
        max = tEnd,
        interval = tEnd,
      },
    },
    { -- l2norm error of velocity
     label = 'L'..level..'_vel_l2norm',
     variable = {
       'diff_vel', 
       'refVelMag' ,
     }, -- variable table
     reduction = {'l2norm', 'l2norm'},
     folder = 'tracking/',
     --shape  = { kind = 'all', },
     shape = {
       kind = 'canoND',
       object = {
         origin = refine_origin,
         vec = {
           refine_vec1, refine_vec2,
         },
         segments = { 2^maxLevel, 2^maxLevel },
       },
     }, -- shape
     format = 'ascii',
      time_control = {
        min = tEnd,
        max = tEnd,
        interval = tEnd,
      },
    },
    { -- l2norm error of pressure
     label = 'L'..level..'_p_l2norm',
     variable = {
       'diff_pressure',
       'refPressure' ,
     },
     reduction = {'l2norm', 'l2norm'},
     folder = 'tracking/',
     --shape = { kind = 'all', },
     shape = {
       kind = 'canoND',
       object = {
         origin = refine_origin,
         vec = {
           refine_vec1, refine_vec2,
         },
         segments = { 2^maxLevel, 2^maxLevel },
       },
     }, -- shape
     format = 'ascii',
      time_control = {
        min = tEnd,
        max = tEnd,
        interval = tEnd,
      },
    },
  } -- track table
} -- scheme table

if track_global then
  table.insert( scheme.tracking,
    { -- whole domain as harvester format
      label = 'L'..level..'_global',
      variable = {
        'pressure_phy',
        'velocity_phy',
        'strainRate_phy',
        'shearstress_phy',
        'refPressure',
        'refVelocityX',
        'refVelocityY',
        'refSxx',
        'refSyy',
      }, -- variable table
      folder = 'tracking/',
      --shape = { kind = 'all', },
      shape = { 
        kind = 'canoND',
        object = {
          origin = refine_origin,
          vec = {
            refine_vec1, refine_vec2,
          },
          segments = { 2^maxLevel, 2^maxLevel },
        },
      }, -- shape
      format = 'harvester',
      time_control = {
        min = 0,
        max = tEnd,
        interval = tEnd,
      },
    }
  ) -- table.insert
end
