require "common"

bounding_cube = {
  origin = bounding_origin,
  length = bounding_length,
}

minlevel = level

spatial_object = {
  {
    attribute = {
      kind = 'seed',
      label= 'seed',
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = { seed_x, seed_y, seed_z },
        -- vec = { l_ch-dx, 0.0,0.0}
      }
    }
  },
  {
    -- Defining a airfoil
    attribute = {
      kind  = 'boundary', -- or seed, refinement
      label = 'airfoil',   -- some label to identify the boundary condition
      level = level,
      calc_dist = false,
    },
    geometry = {
      kind = 'canoND',
      object = airfoil,
    }
  },

  { -- Defining top and bottom planes
    attribute = {
      kind  = 'boundary', -- or seed, refinement
      label = 'top',   -- some label to identify the boundary condition
      level = level,
      calc_dist = false,
    },
    geometry = {
      kind = 'canoND',
      object = {
        { -- top plane
          origin = { start_x, top_y, -dx/2 },
          vec = {
            { bounding_length, 0, 0 },
            { 0, 0, dx*2 },
          },
        },
        { -- bottom plane
          origin = { start_x, bottom_y, -dx/2 },
          vec = {
            { bounding_length, 0, 0 },
            { 0, 0, dx*2 },
          },
        },
      },
    }
  }, -- top and bottom planes

  { -- Defining Z planes
    attribute = {
      kind  = 'boundary', -- or seed, refinement
      label = 'z',   -- some label to identify the boundary condition
      level = level,
      calc_dist = false,
    },
    geometry = {
      kind = 'canoND',
      object = {
        { -- -z plane
          origin = { start_x, start_y, -dx/2 },
          vec = {
            { bounding_length, 0, 0 },
            { 0, bounding_length, 0 },
          },
        },
        { -- +z plane
          origin = { start_x, start_y, dx*1.5 },
          vec = {
            { bounding_length, 0, 0 },
            { 0, bounding_length, 0 },
          },
        },
      },
    }
  }, -- Z planes

  { -- Inlet
    attribute = {
      kind = 'boundary',
      label = 'inlet',
      level = level,
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = { inlet_x, bottom_y, -dx/2 },
        vec = {
          { 0.0, inlet_length, 0 },
          { 0.0,          0.0, dx*2 },
        },
      },
    },
  },
  { -- Outnlet
    attribute = {
      kind = 'boundary',
      label = 'outlet',
      level = level,
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = { outlet_x, bottom_y, -dx/2 },
        vec = {
          { 0.0, outlet_length, 0 },
          { 0.0,           0.0, dx*2 },
        },
      },
    },
  },
}
