-- Musubi configuration file. 
-- This is a LUA script.
require 'common'
inlet = 'ubb'
outlet = 'expol'
tracking_fol = 'tracking/'
restart_fol = 'restart/'


-- Simulation name
simulation_name = 'spacer2D'
-- Mesh information
mesh = 'mesh/'
alance = {active=false, dynamic=false}

-- Time step settings
tmax           =  1--nSteps     -- total iteration number
sim_control = {
  time_control = { 
    max = { iter = tmax },
    interval = { iter=1000 }
  }
}


-- physics setting
fluid = { 
        omega_ramping = {predefined='smooth', min_factor = 0.5, max_factor=1.0, from_time=0, to_time=20000}, 
        omega = omega, rho0 = 1.0 }

interpolation_method = 'compact'                     
-- Initial condition 
initial_condition = { pressure = 1.0, 
                      velocityX = 0.0,
                      velocityY = 0.0,
                      velocityZ = 0.0 }

identify = {label='2D',layout='d2q9',relaxation='bgk'}
-- Boundary conditions
boundary_condition = {  
 { label = 'south', 
  kind = 'wall'} 
,{ label = 'north', 
   kind = 'wall'} 
,{ label = 'west', 
  kind = 'inlet_'..inlet, 
  velocityX = { predefined = 'combined',
              transient= {predefined='smooth', min_factor = 0.0, max_factor=1.0, from_time=0, to_time=20000}, 
              spatial = {predefined='parabol', 
                          shape = { kind = 'canoND', object = { center = {0.0,height/2.0,zpos},halfvec={0.0,height/2.0,0.0}}
                                  }
                          ,amplitude = u_in_L        
                         }         
	      },
   --velocityX = 0.01, 
   velocityY = 0.0, velocityZ = 0.0 }
,{ label = 'east', 
   kind = 'outlet_'..outlet,
   pressure = 1.0}
-- ,{ label = 'bottom', 
--  kind = 'wall'} 
--,{ label = 'top', 
--   kind = 'wall'} 
,{ label = 'sphere', 
   kind = 'wall'}
}

                     

-- Tracking              
racking = {
{
  label = 'vel',
  folder = tracking_fol,
  variable = {'pressure','velocity'}, 
  shape = {kind = 'canoND', object= {origin ={spacer_length/2.0,height/2.0,zpos}} },
  time_control = {
    min = {iter = 1},
    max = {iter = tmax},
    interval= {iter = 100}},  
  format = 'ascii'    
},
{
  label = 'harvester', 
  folder = tracking_fol,
  variable = {'pressure','velocity'}, 
  shape = {kind = 'all' },
  time_control = {
    min = {iter = 1},
    max = {iter = tmax}, 
    interval = {iter = tmax/20}},
  format = 'harvester'      
  },
}
-- restart 
restart = {
      ead = restart_fol..'/spacer2D_lastHeader.lua',
      write = restart_fol,
      time_control = { min = {iter = 0}, max = {iter= tmax}, interval = {iter= tmax/2}}
 }



