-- Musubi configuration file. 

require "common" 

folderRead = 'restart_read/'
folderWrite = 'restart/'

--dt_loc = getdtFromVel( dx, u_in_phy, u_in_L )
--dx = getdxFromLevel( {len_bnd=length_bnd, level=level})
--dt = getdtFromVel( {dx = dx, u_p = u_in_phy, u_l = u_in_L } )
--omega = getOmegaFromdt( {dx=dx, dt=dt, nu_p = nu_phy } )

ref_press = ( rho0_L*cs2 ) * ( rho0_p * (dx*dx) / (dt*dt) )
press_grad = 1e-2*cs2

-- Simulation name
simulation_name = 'channel2D'
--mesh = 'mesh_sph/' -- Mesh information
mesh = 'mesh/' -- Mesh information
printRuntimeInfo = false
control_routine = 'fast'
-- Time step settigs
tmax_p = 1 --s
tmax =  50000--tmax_p/dt    -- total iteration number
interval_p = tmax_p/10
interval = 1000
sim_control = {
  time_control = { 
    max = {sim=tmax_p,iter=tmax}, 
    interval = {sim=interval_p,iter=interval}
   },
  abort_criteria = {
    stop_file = 'stop',
    steady_state = true
  }
}

restart = {
      ead = 'restart/channel2D_lastHeader.lua',
      write = 'restart/',
      -- without timeControl table restart will be dumped at last timestep
      --time_control = { min = 0, max = {sim=tmax_p,iter=tmax}, interval = dt*100},
      time_control = { min = 0, max = {sim=tmax_p,iter=tmax}, interval = {iter=interval}},
}

--debug = { debugMode = true, debugFiles = true, debugNormal = true,
--          debugMesh = './debug/mesh_', debugStates = { 
--  write = {
--    folder    = './debug/',    -- the folder the restart files are written to
--    interval  = 1,           -- dump restart file interval
--    tmin      = 0,           -- first timestep to output
--    tmax      = tmax+1       -- last timestep to output
--    }
-- }} 


fluid = { 
        --!omega_ramping = {predefined='smooth', min_factor = 0.5, 
        --                    max_factor=1.0, from_time=0, to_time=10000.0*dt}, 
           --kine_shear_viscosity = nu_phy,
           omega = omega,
           rho0 = rho0_p }

interpolation_method = 'linear'                     

originX_1 = length/2.0
originX_2 = 0.
originY = .0
originZ = .0
pulse_size = length/20.
halfwidth = pulse_size
amplitude = 0.0001
background = ref_press

function ic_1Dgauss_pulse(x, y, z)
  return background+amplitude*math.exp(-0.5/(halfwidth^2)*( x - originX_1 )^2)
  --return background+amplitude*math.exp(-0.5/(halfwidth^2)*( y - height/2.0 )^2)
end
function ic_2Dgauss_pulse(x, y, z)
  return background+amplitude*math.exp(-0.5/(halfwidth^2)*(( x - originX_2 )^2+( y - originY )^2))
end

-- Initial condition 
initial_condition = { 
                      pressure = ref_press, 
                      --pressure = ic_1Dgauss_pulse, 
                      velocityX = 0.0,
                      velocityY = 0.0,
                      velocityZ = 0.0 }

identify = {label='bgk',layout='d2q9', relaxation='bgk',
            kind = 'lbm_incomp'
            }

-- needed to dump variable in physical unit
physics = { dt = dt, rho0 = rho0_p }            
-- Boundary conditions
boundary_condition = {  
  {
    label = 'west', 
    --kind = 'wall',
    --kind = 'moments_wall',
    --kind = 'moments_press',
    pressure = ref_press+press_drop,
    --pressure = ref_press+press_grad,
    --pressure = 1.001*cs2 --ref_press+press_grad
    kind = 'moments_vel', 
    --kind = 'inlet_eq',
    --velocityX = u_in_phy,
    velocityX = u_inflow,
    elocityX = { kind = 'combined',
                  temporal = {predefined='smooth', min_factor = 0.0, 
                              max_factor=1.0, from_time=0, to_time=100*dt}, 
                  spatial = {predefined='parabol', 
                             shape = { kind = 'canoND', object = {origin  = {0.0,0.0,zpos},
                                                                  vec = {0.0,height,0.0} } 
                             }
                            ,amplitude = u_in_phy 
                  }         
                                    
    	      },
   velocityY = 0.0, velocityZ = 0.0},
  {
    label = 'east',
    --kind = 'wall',
    kind = 'moments_press',
    --kind = 'outlet_eq',
    --kind = 'moments_wall',
    --pressure =  0.999*cs2 --ref_press-press_grad
    pressure =  ref_press
  }, 
  {   
    label = 'north', 
    kind = 'moments_wall' ,
--   kind = 'slip_wall',
   --kind = 'wall',
   fac = 1.0 
  },
  {
    label = 'south', 
    kind = 'moments_wall', 
   --kind = 'slip_wall',
   --kind = 'wall',
   fac = 1.0 
  },
  {
    label = 'obs',
    --kind = 'moments_wall'
    kind = 'wall'
  }
 }

-- Tracking              
tracking = {
{
  label = 'probe', 
  folder = 'tracking/',
 variable = {{'pressure_phy'},{'velocity_phy'}}, 
 shape = {kind = 'canoND', object = {origin ={length*0.5,height*0.5,zpos} } },
 time_control = {min= {iter= 1}, max = {iter= tmax}, interval = {iter= 10}},
  format = 'ascii'      
},
{
  label = 'prsDrop', 
  folder = 'tracking/',
 variable = {{'pressure_phy'}}, 
 shape = {kind = 'canoND', object = {origin ={0.0,height*0.5,zpos},
                                     vec = {length,0.0,0.0},
                                     segments = nLength+2} },
 time_control = {min = {iter= tmax}, max = {iter= tmax}, interval = {iter= tmax+1}},
  format = 'asciiSpatial'      
},
{
  label = 'velProfile', 
  folder = 'tracking/',
 variable = {{'velocity_phy'}}, 
 shape = {kind = 'canoND', object = {origin ={length*0.5,0.0,zpos},
                                     vec = {0.0,height,0.0},
                                     segments = nHeight+2} },
 time_control = {min = {iter= tmax}, max = {iter= tmax}, interval = {iter= tmax+1}},
  format = 'asciiSpatial'      
},
{ label = 'convergence',
  variable = {{'pressure_phy'}}, 
  shape = {kind = 'canoND', object = {origin ={length*0.5,height*0.5,zpos} } },
  time_control = {min = 0, max = tmax_p, interval = 10*dt},
  format='convergence',
  convergence = {norm='average', nvals = 50, absolute = true,
  condition = { threshold = 1.e-8, operator = '<=' }}
}
}


