--interpolation_method = 'quadraticCompact'
--interpolation_method = 'quadratic'
--interpolation_method = 'linear'
interpolation_method = 'average'
outputpreview = false

-- common header --
level =  6 
refinementLevel = 1  
label = 'channel'
idLabel = 'channel'
u_in = 0.02
-- geometry definition
length = 2.05
height =  3./16.*length
radius = 0.05
usePeriodic = false
useObstacle = true
useCylinder = true
cylOrientation = 'Z'
testIntersection = false

if useObstacle == true then
  refOmega = 1.98
  refLevel = 7
else
  refOmega = 1.9
  refLevel = 6
end
--
m = 2^(refLevel - level)
omega = 1./(1/m*(1/refOmega -0.5)+0.5)
maxLevel = level+refinementLevel

dx     = length/(2^level)
dxMin  = length/(2^maxLevel)
dxDash = 0.5*dxMin
viscLB = 1/3*(1/omega-1/2)
-- physical reference values
dxPhys = dx
lPhys = length  -- m
csPhys = 300    -- m/s
csLB = 1/math.sqrt(3)
--acoustic scaling with speeds of sound as reference
-- csPhys = csLB * dxPhys / dtPhys
dtPhys = csLB/csPhys*dxPhys
rho0 = 1  -- kg/m^3
viscPhys = viscLB*dxPhys^2/dtPhys


nElemsMax = 2^maxLevel
if useObstacle == true then
  nIters = nElemsMax*40
else
  nIters = nElemsMax*40
end
nIters = nElemsMax*40


-- Use this file as template. Do not modify this file for running some testcases
outputname = 'channel_2D'
folder = 'mesh/' 

-- general refinement levels
-- minrefine: defines minimum refinement level of the entire domain
--
-- maxrefine: defines maximum refinement
-- gets overwritten from madatory STL levels
-- (deprecated - used only for spacer stuff right now)
-- will become default for stl refinement level once
-- it is not mandatory any more
minlevel = level
-- stl_files: for each stl file put a table into
-- this table of tables. Or just a string for
-- the filname, if the other two parameters should
-- get the default: boundary_type = 1, fileformat = 'binary'
-- refinementlevel is the level to which the stl shall be refined
-- it is mandatory

seederLength = length+dx


size_x = 0.3*length
start_x = -0.15*length
if useObstacle then
  size_x = 0.63*length
  start_x = -0.42*length
  size_y = height/2-2.*dxDash
  if testIntersection then
    start_x = -0.35*length
  end
else
  size_y = height/3-2.*dxDash
end
start_y = -size_y/2
size_z = size_y
start_z = start_y
if useCylinder then
  if cylOrientation=='Y' then
    size_z  = size_y
    start_z = start_y
    size_y  = 3*size_y
    start_y = 3*start_y
  else
    size_z  = 3*size_y
    start_z = 3*start_y
  end
end

-- boundingbox: two entries: origin and length in this
-- order, if no keys are used
bounding_cube = {origin = {-seederLength*0.5, -seederLength*.5, -seederLength*0.5},
               length = seederLength}

    -- refinebox: three entries: origin, length and refinementlevel
    refinebox = {{origin = {-length*0.5, -height*.5, -0.5*height},
                length = {length, height, height},
                refinementlevel = level
                }
                }
    table.insert( refinebox, 
         {origin = {start_x, start_y, start_z }, 
          length = {size_x, size_y, size_z}, 
          refinementlevel = minlevel
                  }) 
-- seed: position of seed 
spatial_object = {
  {
    attribute = {
      kind = 'seed',  ------seed
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = {0.0, 0.0, dx*0.5},
        } --- object
    }
  },
  {
    attribute = {
      kind = 'refinement',
      level = refinementlevel
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = {-length*0.5, -height*.5, -0.5*height},
                 length = {length, height, height},

      }
    }  
  },
  {
    attribute = {
      kind = 'boundary',  ---kind in attribute is seed/boundary/refinement/periodic
      label = 'east'     -- for east
    },
    geometry = {
      kind = 'canoND',    -- kind in geometry is canoND/sphere/stl 
      object = {
        origin ={length*0.5,-length*0.5,-length*0.5},
        vec = {{0.0,length,0.0},
               {0.0,0.0,length}}
        }
    }
  },
  {
    attribute = {
      kind = 'boundary',
      label = 'west'    --- for west
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin ={-length*0.5,-length*0.5,-length*0.5},
        vec = {{0.0,length,0.0},
               {0.0,0.0,length}}
        }
    }
  },
  {
    attribute = {
      kind = 'boundary',
      label = 'north'     --- for north
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = {-length*0.5,height*0.5+dxDash,-length*0.5},
        vec = {{length,0.0,0.0},
               {0.0,0.0,length}}
        }
    }
  },
  {
    attribute = {
      kind = 'boundary',
      label = 'south'     --- for south
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = {-length*0.5,-height*0.5-dxDash,-length*0.5},
        vec = {{length,0.0,0.0},
               {0.0,0.0,length}
        }
      }
    }
  }
}
if useObstacle ==true then
  if useCylinder == true then
    if cylOrientation =='Z' then
      table.insert( spatial_object,
      {
        attribute = {
          kind = 'boundary',
          label = 'obs'    --- for south
        },
        geometry = {
          kind = 'stl',
          object = {
            filename = 'cylinder.stl'
          }
        }
      })

   elseif cylOrientation=='none' then
   elseif cylOrientation=='mini' then
     table.insert( spatial_object,
     {
      attribute = {
        kind = 'boundary',
        label = 'obs'    
      },
      geometry = {
        kind = 'stl',
        object = {
          filename = 'cylinder_mini.stl'
        }
      }
    })
   else
     table.insert( spatial_object,
      {
        attribute = {
          kind = 'boundary',
          label = 'obs'    --- for south
        },
        geometry = {
          kind = 'stl',
          object = {
            filename = 'cylinderY.stl'
          }
        }
      })
  end
else 
 table.insert( spatial_object,
      {
        attribute = {
          kind = 'boundary',
          label = 'obs'    --- for south
        },
        geometry = {
          kind = 'sphere',
          object = {
            {
              radius = radius,
              origin = {-length*0.35,-0.01*height,0.}
            }
         }
       }
    })
  end
end

  if usePeriodic == false then
    table.insert( spatial_object,
   {
    attribute = {
      kind = 'boundary',
      label = 'front'    --- for south
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin = {-length*0.5,-length*0.5,height*0.5+dxDash},
        vec = {{length,0.0,0.0},
               {0.0,length,0.0}
        }
      }
    }
  })
  table.insert( spatial_object,
  {
    attribute = {
      kind = 'boundary',
      label = 'back'     --- for east
    },
    geometry = {
      kind = 'canoND',
      object = {
        origin ={-length*0.5,-length*0.5,-height*0.5-dxDash},
        vec = {{length,0.0,0.0},
               {0.0,length,0.0}}
       }
     }
  })
end

if usePeriodic ==true  then
  table.insert( spatial_object,
  {
    attribute = {
      kind = 'periodic', --kind is periodic
    },
    geometry = {
      kind = 'periodic',
      object = {
        plane1 = {
          origin ={-length*0.5,-length*0.5, dx+dxDash},
          vec = {{length,0.0,0.0},
                {0.0,length,0.0}}
        },  --- plane1
        plane2 = {
          origin = {-length*0.5,-length*0.5,-dxDash},
          vec = {{0.0,length,0.0},
                  {length,0.0,0.0}}
        } --- plane2        
      } 
    }
  })
end

