# Author: Manuel Hasert
# Gleaner parameter file. It parses the given resultFolder for valid 
# simulation results and passes it to gleaner. 
# As a result a database permeability.db is generated containing the results:
# * Darcy-Reynolds number
# * friction coefficient
# * level (of the simulation, i.e. the resolution)
# * model (of the simulation, i.e. mrt, trt etc)
# * porosity of the medium
#
import math
import re
import os
import sqlite3 as lite

# User defined 
viscosity= 0.00001    # fluid viscosity in m^2/s
rho0      = 1.0       # fluid density kg/m^3
length    = 0.000806  # length over which  the pressure drop is measured 
                      # The effective pressure drop occurs over the porous medium itself.
                      # so here, you must give the x-length of the porous medium in [m]
poresize  = 0.000080  # average pore size of the measured porous medium in [m] 80 um = 80*10^-6 

# the result folder to be parsed by this script
resultFolder = 'prod_dpStudy'
#resultFolder = 'prod_dpStudy_clear/mesh_level0refine0/inputu0LB0.0003dp500scalingdiffusiveomega1.95reltrtmodellbm_incomp'


#-----------------------------------------------------------------------
plot  = []
show_plot = False

files = ['*flowRate*.res', 
         '*pressureIn*.res',
         '*pressureOut*.res',
         '*porosity*.res']

folders = []
# Set up the list of simulation folders in the results directory
for dirname, dirnames, filenames in os.walk(resultFolder):
  isSimDir = False
  # if I find tracking as subdirectory, mark as a simulation directory
  if 'tracking' in dirnames:
    isSimDir = True
  # if it was marked as a simulation directory, append it to the folder list
  if isSimDir:
    folders.append(dirname)

print 'Found simulation folders:'
print folders

# directory loop
for iFolder in range(len(folders)):
  print 'acting on folder', folders[iFolder], files[0], files[1], files[2], files[3]
  ## xy plot 
  plot.append(dict(kind = 'permeability',
              data=[folders[iFolder]+'/tracking/'+files[0], 
                    folders[iFolder]+'/tracking/'+files[1], 
                    folders[iFolder]+'/tracking/'+files[2], 
                    folders[iFolder]+'/tracking/'+files[3] ],
             row=[0,-1],col=[1,2]
             , label  = folders[iFolder]  ))
