#
# Author: Manuel Hasert
# 
# Description: This python file reads in the permeability.db database generated from the 
# Gleaner runs with kind='permeability'
# In that run, all results are collected into the database.
# Here, we extract values from that database to generate custom plots, such as
#  friction coefficient for certain models or runs over the Reynolds number
import math
import re
import os
import sqlite3 as lite


def is_number(s):
  try:
    float(s)
    return True
  except ValueError:
    return False

# Set the gnuplot style
style = ' w lp '

# Now open the database and extract values for curves
# model+level: friction coefficient over ReD
# try: 
con = lite.connect('permeability.db')
with con:    
  cur = con.cursor()    
  cur.execute("SELECT DISTINCT level FROM permeability")
  levels = cur.fetchall()
  cur.execute("SELECT DISTINCT model FROM permeability")
  models = cur.fetchall()

  # extract porosity over levels
  for level in levels:
    cur.execute("SELECT DISTINCT porosity FROM permeability WHERE level = ?", level)
    tests = cur.fetchall()
    for porosity in tests:
      print level, 'porosity', porosity

  # Generate gnuplot file
  filename = 'plot.gpl'
  gpl = open( filename, 'w')
  gpl.write('set ylabel \'Friction coefficient \'\n')
  gpl.write('set xlabel \'ReD\'\n')
  gpl.write('set logscale x\n')
  gpl.write('plot \\\n')

  # extract friction coefficient over ReD for model and level
  for model in models:
    for level in levels:
      filename = 'level'+str(level[0])+'model'+model[0]+'.res'
      f = open( filename, 'w')
      print 'treating current model',model[0]
      print 'treating current level',level[0]
      # generate the arguments to extract from the database
      t = (model[0], '%s'%level[0] )
#      cur.execute("SELECT ReD,frictionCoefficient, darcyCoeff FROM permeability WHERE model = ? AND level = ? ORDER BY ReD", t)
      cur.execute("SELECT ReD,frictionCoefficient FROM permeability WHERE model = ? AND level = ? ORDER BY ReD", t)
      tests = cur.fetchall()
      for stuff in tests:
        print 'stuff', stuff
        if is_number( str(stuff[0])) and is_number( str(stuff[1])):
          string = str(stuff[0])+'     \t'+str(stuff[1])+'\n'
          f.write( string  )
      f.close()
      print 'models', models
      print 'list position', models.index( model )
      print 'list position', len ( models)-1
      if models.index( model ) == len( models )-1:
        lastModel = True
      else:
        lastModel = False
      if levels.index( level ) == len( levels )-1:
        lastLevel = True
      else:
        lastLevel = False
      if lastModel and lastLevel:
        endstring = '\n'
      else:
        endstring = ',\\\n'
      
      string = '\''+filename+'\''+ style +' t \''+str(model[0])+str(level[0]) +'\''+ endstring
      gpl.write( string )

  # Write the rest of gnuplot
  gpl.write(' pause -1')
  gpl.close()


