-- add the relative paths to your common luas here from the seeder.lua and the musubi.lua
-- in the prod directories
--package.path = package.path ..';../../?.lua'..';../../../?.lua'
--
-- Seeder.lua for measuring the permeability of an object
-- Please only alter this script up to the warning given
--
-- reading the argument to decide for stent or porous (or whatever testcase)
-- define the case by setting case=stent or case=porous in the bash
shepherdRun = false
if shepherdRun == false then
  verbose = true
else
  verbose = false
end
case = os.getenv("case")
--
if case then
  print('********************************************************************************************')
  print('')
  print('Running the script with ', case, 'stent configuration!!')
  print('')
  print('********************************************************************************************')
else
  print('********************************************************************************************')
  print('')
  print('No case has bee selected. Please select "stent" or "porous" as command line argument!!'      )
  print('  export case=porous ')
  print('********************************************************************************************')
end 
--
--*****************************************************************************
--                   define general seeder parameters
--*****************************************************************************
-- To run this script the following parameters have to be defined in the 
-- associated common lua file:
-- * the reference level of you grid (the minimum level you want to run your 
--   simulation on); refLevel
-- * the length before and after the porous medium in terms of ratio to the 
--   porous medium length; addLength_before, addLength_after
-- * the dimensions and the origin of the porous medium; sizePorous, 
--   originalOrigin
-- * the porous medium in seeder table format and the belonging label; 
--   spatial_object, obj_label
-- 
-- The following ones in this file:
-- * the refinement ...; refinement
-- * the number of refinement steps; nRefine
-- * the interpolation method; interpolation_method
-- * include your common lua file
--
-- parameters for multilevel
refinement=0
interpolation_method = 'quadratic'

--
------------------------------------------------------------------------------
-- WARNING!! 
-- Do not change anything from here unless you know exactly what you are doing
------------------------------------------------------------------------------
--
-- stent or porous medium??
if case == 'stent' then
  require 'stentCommon'
elseif case == 'porous' then
  require 'porousCommon'
else
  print('********************************************************************************************')
  print('')
  print('Selected case is not available. Please select "stent" or "porous" as command line argument!!')
  print('')
  print('********************************************************************************************')
end
--
-- actual and maximum level used for the seeder
level = refLevel -- + ${level}$
maxLevel= level + refLevel

-- origin of the porous medium
  originPorous = {
  -sizePorous[1]/2., 
  -sizePorous[2]/2., 
  -sizePorous[3]/2.
  }
--
-- Bounding cube length and origin
lengthX = sizePorous[1]*(1. + addLength_before + addLength_after)
height = math.max( sizePorous[2], sizePorous[3] )
startX = originPorous[1] - sizePorous[1]*addLength_before
startLength = sizePorous[1]*addLength_before
endLength = sizePorous[1]*addLength_after 
-- is the porous object bigger in y,z or x direction?
length = math.max( lengthX, height )
-- dx on the reference level
dx_ref = length/(2^refLevel) 
-- dx on this level
dx = length/2^(level)
--print( ' height         ', height )
--print( ' lengthX        ', lengthX)
--print( ' length         ', length)

---------------------------------------------------------------
-- check if the length before and after correspond to enough elements
minElems = 15
changed = false
nElems_before = addLength_before*sizePorous[1]/dx
if nElems_before < minElems then
  -- recalculate addLength_before with 10 elements
  addLength_before = minElems*dx/sizePorous[1] 
  changed = true
end 
nElems_after = addLength_after*sizePorous[1]/dx
if nElems_after < minElems then
  -- recalculate addLength_before with minElems
  addLength_after  = minElems*dx/sizePorous[1] 
  changed = true
end 
-- recalculate?
if changed then
  print(' Recalculating the before and after regions as there were not enough elements encountered')
  -- Bounding cube length and origin
  lengthX = sizePorous[1]*(1. + addLength_before + addLength_after)
  height = math.max( sizePorous[2], sizePorous[3] )
  startX = originPorous[1] - sizePorous[1]*addLength_before
  startLength = sizePorous[1]*addLength_before
  endLength = sizePorous[1]*addLength_after 
  -- is the porous object bigger in y,z or x direction?
  length = math.max( lengthX, height )
--  print( ' height         ', height )
--  print( ' lengthX        ', lengthX)
--  print( ' length         ', length)
  -- dx on the reference level
  dx_ref = length/(2^refLevel) 
  -- dx on this level
  dx = length/2^(level)
end
-- check if the length before and after correspond to enough elements
---------------------------------------------------------------

-- set the bounding cube origin and end
origin  = { startX,
            -length*0.5,
            -length*0.5 }
endX = { origin[1]+lengthX, origin[2]+length, origin[3]+length}
--
-- number of elements on the reference level
nRefElems = { 
  math.floor( sizePorous[1]/2./dx_ref ), 
  math.floor( sizePorous[2]/2./dx_ref ), 
  math.floor( sizePorous[3]/2./dx_ref )
}

--
-- is the channel length greater than its height??
if height < lengthX then
  longChannel = true
end
--
simname = 'porous'
idLabel = 'permeability'
--
-- minimal dx on the provided level (for multilevel)
dxMin = length/2^(maxLevel)
-- maximum number of elements
nElemsMax = 2^maxLevel
--
--
-- number of elements in x-direction, only valid for single level
nLength = math.floor(lengthX/dx)
-- number of elements in the y-,z-direction, only valid for single level
nHeight = math.floor(heightPorous/dx)
--
--
-- check if the refinment level is high enough
if nLength < 10 then
  print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
  print('The number of elements in x direction is ',nLength     )
  print('which is less than 10. Please increase the level!     ')
  print('The number of elements in the height is ',nHeight      )
  print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
end
--
-- setting the level defined offset for the stent (spacer)
if case == 'stent' then
  -- adjust the spacer origins
  spatial_object[1].geometry.object.length.origin[3] = spatial_object[1].geometry.object.length.origin[3] + dx
  spatial_object[1].geometry.object.width.origin[2] = spatial_object[1].geometry.object.width.origin[2] + dx
end
--
-- updating the level for the spatial object (porous/stent) to be maxLevel for
-- local refinement
spatial_object[1].attribute.level = maxLevel
--
-------------------------------------------------------------------------------
comment = 'permeability of porous medium'
folder = 'mesh/' --MESH
--
minlevel = level
-- define the bounding cube
bounding_cube = { 
  length = length, 
  origin = origin
  }
-- debug mode active??
ebug = {debugMode = true }
--
-- Move porous medium to be centered at origin in case of stl input
if spatial_object[1].geometry.kind == 'stl' then
  spatial_object[1]['transformation'] = 
  {
            translation = {
              -(originalOrigin[1] + sizePorous[1]*0.5),
              -(originalOrigin[2] + sizePorous[2]*0.5),
              -(originalOrigin[3] + sizePorous[3]*0.5)
              } 
            }
end
--
--*****************************************************************************
--                Add the seed, walls, in- and outlet
--*****************************************************************************
table.insert( spatial_object, 
   {
    -- Defining a seed to identify the part of the computational domain in
    -- the universe cube.
    attribute = { kind = 'seed' },
    geometry = { -- single point definition with a canoND object.
                 kind = 'canoND',
                 object = { origin = { 
                   origin[1] + 1.5*dx, 
                   originPorous[2]+sizePorous[2]*0.5, 
                   originPorous[3]+sizePorous[3]*0.5
                   } 
                 }
               }
  }) 
--
table.insert( spatial_object, 
{ -- Inlet
    attribute = { kind = 'boundary',
                  label = 'inlet'
                },
    geometry = { 
      kind = 'canoND',
      object = {
         origin = {origin[1]+dx*0.5, origin[2], origin[3]},
         vec = {
                {0.,length,0.0},
               {0.0,0., length} }
      }
   }
  }) 
--
table.insert( spatial_object, 
  { -- Outlet
    attribute = { kind = 'boundary',
                  label = 'outlet', 
                },
    geometry = { 
      kind = 'canoND',
      object = {
         origin = {endX[1]-dxMin*0.5, origin[2], origin[3]},
         vec = {
                {0.,length,0.0},
              {0.0,0., length} } 
      }
   }
  })
--
-- position of the channel walls
wallPos = { 
  (nRefElems[1]-1)*dx_ref+0.001*dxMin, 
  (nRefElems[2]-1)*dx_ref+0.0001*dxMin, 
  (nRefElems[3]-1)*dx_ref+0.0001*dxMin 
}
--
-- modify the wall position dependend of the shape of the channel
if longChannel then
  wallPos[1] = wallPos[1] + dx_ref
  wallPos[2] = wallPos[2] + dx_ref
  wallPos[3] = wallPos[3] + dx_ref
end
--
if verbose then
  print('walPosition: ', wallPos[1], wallPos[2], wallPos[3])
end
table.insert( spatial_object, 
  { -- Channel Walls
    attribute = { kind = 'boundary',
                  label = 'channel', 
                },
    geometry =  {
      kind = 'canoND',
      object = {
      {  -- y-
         origin = {origin[1], -wallPos[2], originPorous[3]},
         vec = {{ length,0.,0.0},
              {0.0,0., sizePorous[3]}}
      },
      {  -- y+
         origin = {origin[1], wallPos[2], originPorous[3]},
         vec = {{ length,0.,0.0},
              {0.0,0., sizePorous[3]}}
      },
      {  -- z-
         origin = {origin[1], originPorous[2], -wallPos[3]},
         vec = {{ length,0.,0.0},
              {0.0,sizePorous[2],0.}}
      },
      {  -- z+
         origin = {origin[1], originPorous[2], wallPos[3]},
         vec = {{ length,0.,0.0},
              {0.0,sizePorous[2],0.}}
      },
    }
  }})
--
-- end of spatial objects
-- ************************************************************************ --
