--
-- This file defines some input parameters for the seeder and musubi for the 
-- stent (spacer) case.
--
--
--*****************************************************************************
--                 define the parameters for the stent
--*****************************************************************************
--
-- minimum number of pores along the channel height (this is checked against)
min_pores = 15
--
-- strut diameter in m
strut_dia = 0.000025
--
-- size of the pores in the stent in m^2
pore_size = 0.00000004
--
-- User defined 
-- Set here the bounding box origin (originalOrigin) 
-- the size of the bounding box sides (sizePorous) in m
--
-- basic height of the porous medium (stent)
heightPorous = 0.0034
-- number of pores of the porous medium (stent)
nPores = math.floor( heightPorous / ( math.sqrt(pore_size) + strut_dia ))
lengthPorous = 2.*strut_dia
sizePorous   = {lengthPorous, heightPorous, heightPorous}
originalOrigin = {0.0, -heightPorous/2., -heightPorous/2.}
--
--*****************************************************************************
--                     set channel parameters
--*****************************************************************************
--
-- How much space should be left before and after?
-- ratio to porous length
addLength_before = 20.
addLength_after  = 20.
--
-- this is calculated in the seeder.lua once more but it needs to be here
c_length = sizePorous[1]*(1. + addLength_before + addLength_after)
--
maxHeight = math.max( sizePorous[2], sizePorous[3] )
bc_length = math.max( c_length, maxHeight )
--
-- define the minimum refinement level based on the strut diameter
-- (for multilevel simulations this might be adapted)
refLevel = math.floor(math.log(maxHeight/strut_dia)/math.log(2))
--
-- dx on the reference level
dx_ref = bc_length/(2^refLevel) 
--
-- number of elements on the reference level
nRefElems = { math.floor( sizePorous[1]/2./dx_ref ),
              math.floor( sizePorous[2]/2./dx_ref ), 
              math.floor( sizePorous[3]/2./dx_ref )}
--
-- check if the number of pores is sufficient
if min_pores < nPores then
  print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
  print('The minimum number of pores is less than what can be  ')
  print('set for this height. Please increase the height!      ')
  print('minPores: ', min_pores, ' vs ', nPores)
  print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
end
--
-- define some more parameters for the stent (spacer)
--
-- stent (spacer) input arguments in m
sp_filament_gap1 = math.sqrt(pore_size)+strut_dia
sp_orig1 = {originalOrigin[1]+strut_dia, originalOrigin[2], originalOrigin[3]+sp_filament_gap1/2.}
sp_vec1 = {0.0, sizePorous[2], 0.0}
sp_radius1 = strut_dia/2.0
--
sp_filament_gap2 = math.sqrt(pore_size)+strut_dia
sp_orig2 = {originalOrigin[1]+strut_dia, originalOrigin[2]+sp_filament_gap2/2., originalOrigin[3]}
sp_vec2 = {0.0, 0.0, sizePorous[3]}
sp_radius2 = strut_dia/2.0
--
---- Add your porous medium here
--
-- define the name of the porous medium / stent
obj_label = 'stent'
--
--
spatial_object = {
  {
    -- Defining a domain boundary
    attribute = {
      kind = 'boundary',
      label = obj_label,
      level = 0           -- level to refine this object with,
                          -- default = 0, this will be updated to maxLevel 
                          -- in the seeder.lua
    },
    -- Defining the stent geometry
    geometry = {
      kind = 'spacer',
      object = {
        length = {
          vec = sp_vec1,
          filament_gap = sp_filament_gap1,
          radius = sp_radius1,
          origin = sp_orig1
        },
        width = { 
          vec = sp_vec2,
          filament_gap = sp_filament_gap2,
          radius = sp_radius2,
          origin = sp_orig2
        },
          interwoven = true
      }
    }
  }
}
