require "common"

function refFunction()
  return 0
end
-- Musubi configuration file. 
-- This is a LUA script.

-- Simulation name
simulation_name = 'gaussPulse1d'
mesh = 'mesh/' -- Mesh information

nElems = 2^(maxLevel)
--print('maximum number of elements in COS'..nElems)
-- Time step settigs
tmax   = nIters
sim_control = {
  time_control = {
    min= {iter= 1},
      max= {iter= tmax},
        interval = {iter = tmax/10}
  }
}

--debug = {debugMode = true, debugFiles = true}

fluid = { 
       omega = omega, 
       rho0 = 1.0 }

originX = -0.3*length
originX2 = 10.05
originY = -0.5*length + 0.65*length
originZ = 00.0
halfwidth = gaussPulse_halfwidth
amplitude = 0.001
background = 1.0

radius_rot = 0.2
circulation = 0.1

function ic_1Dgauss_pulse(x, y, z, t)
  return background+amplitude*math.exp(-0.5/(halfwidth^2)*( x - originX )^2) --+amplitude*math.exp(-0.5/((halfwidth*1.0)^2)*( x - originX2 )^2)
end
function ic_1Dgauss_pulse2(x, y, z, t)
  return background+amplitude*math.exp(-0.5/(halfwidth^2)*( x - originX2 )^2)
end
function ic_2Dgauss_pulse(x, y, z, t)
  return background+amplitude*math.exp(-0.5/(halfwidth^2)*(( x - originX )^2+( y - originY )^2))
end
-- Initial condition 
initial_condition = { pressure = ic_1Dgauss_pulse, 
                      velocityX =0.0, --{ predefined = "crvpX", 
                               --    radius_rot = radius_rot,
                               --    circulation= circulation,
                               --    center = { 0.0, 0.0, 0.0 } },
                       velocityY =0.0, --{ predefined = "crvpY", 
                                   --radius_rot = radius_rot,
                                   --circulation= circulation,
                                   --center = { 0.0, 0.0, 0.0 } },
                      velocityZ = 0.0 }

identify = {label='square',layout='d2q9'}

-- Output settings
utput = { active = true, -- VTU output activated?
  folder = './output/', --_l'..level..'/',     -- Output location
  --dumpGhosts = true,
  vtu = true,             -- VTU output activated?
  time_control = {min = {iter= 0}, max ={iter= -1}, interval= {iter= 1}}
}

variable = {
  { name = 'spacetime', 
    ncomponents = 1, 
    vartype='st_fun', 
    st_fun = refFunction},
  {  name = 'diff_press_st', 
     ncomponents = 1, 
     vartype = 'operation',
     operation = {
       kind = 'difference',
       input_varname = {'pressure', 'spacetime'} 
     }
   },
}
-- Tracking              
tracking = {
  {
  -- tracking object for getting the error in terms of the l2norm
  label = label..'_error_l'..level, 
  variable = { 'diff_press_st'},
  reduction = {'l2norm' },
  --reduction = {operation = 'sum', variable = {'difference'}},
  shape = {kind = 'canoND', object = {origin ={-0.5,0.,0.}, vec = {1.0, 0.0, 0.0}, segments = 10*nElems } },
  time_control = {min = {iter= tmax}, max = {iter= -1}, interval ={iter= 1}},
  format = 'ascii',
  folder = './tracking/'
 }, 
 {
  -- tracking object for the spatial representation of the pressure
  label = label..'_spatial_l'..level, 
  variable = { 'density', 'spacetime', 'diff_press_st'},
  shape = {kind = 'canoND', object = {origin ={-0.5,0.,0.}, vec = {1.0, 0.0, 0.0}, segments = 10*nElems } },
  time_control = {min = {iter= tmax}, max = {iter= tmax}, interval= {iter = 1}},
  format = 'asciiSpatial',
  folder = './tracking/'
  }
}
