require "complex"

I = math.i

level = tonumber(os.getenv("level"))
Re = tonumber(os.getenv("Re"))
alpha = tonumber(os.getenv("womersley"))
if level == nil then
  level = 7
end
if Re == nil then
  Re = 30
end
if alpha == nil then
  alpha = 4
end

nT = 2 -- number of periods for whole simulation

simulation_name = 'womersley2D'
label = 'L_'..level..'_Re_'..Re..'_Wo_'..alpha
mesh = 'mesh/'
diffusive = true
printRuntimeInfo = false
scaling = 'diffusive'
multi_level = 0
logging = { level = 3, }
control_routine = 'fast'

kind       = 'lbm'
relaxation = 'mrt'
layout     = 'd2q9'
if Re == 30 then
  omega = 1.9
elseif Re == 300 then
  omega = 1.9
end
height = 1.0
length = 4.0 * height
dx = length / (2.^level)
top_y    =  height/2 + dx/2
bottom_y = -height/2 - dx/2
inlet_x  = -length/2 + dx/2
outlet_x =  length/2 - dx/2
--length = outlet_x - inlet_x - dx*2

ly = height / dx       -- number of elements in Height
lx = length / dx - 2   -- number of elements in Length
R  = height / 2

-- Physical parameters
densityPhy = 1.0
T = 1.0 -- period ( unit: s )
w = math.pi * 2 / T -- angular frequency ( unit: rad/s )
nuPhy = w * R * R / alpha / alpha
viscPhy = nuPhy * densityPhy
-- Stokes layer thickness
stokes = math.sqrt( 2 * nuPhy / w )
-- Re = Umax * height / nu
velMaxPhy = Re * nuPhy / height
-- Umax = R*R / 2 / viscPhy * dp_dx
dp_dx = velMaxPhy * 2 * viscPhy / R / R

-- reference LB quantities
rho0 = 1.
cs2  = 1./3.
cs   = math.sqrt(cs2)
p0LB = rho0*cs2
nuLB = ( 1.0 / omega - 0.5 ) / 3.0   -- viscosity
Tmom = math.floor(ly * ly / nuLB)
Ts   = math.floor(lx / cs)
dt   = nuLB * dx * dx / nuPhy
TLB  = math.floor(T/dt) -- number of iteration for one period
tmaxLB = TLB * nT
tmax = tmaxLB
velMaxLB = velMaxPhy / dx * dt
Mach = velMaxLB / cs
p0Phy = 0
tmaxPhy = tmaxLB * dt
dp = dp_dx * ( length - dx )
dpLB = dp *dt*dt / dx / dx / densityPhy

-- Analytical solutions
-- Strain Rate
function strainRateA(x, y, z)
  return -1*(y) * velMaxPhy / R / R * 2
end

-------------------------------------------------------------------------------
-- analytical solution from paper
-- normalized Velocity = vel / umax
c1 = ( alpha + I*alpha ) / math.sqrt(2.0)
c2 = dp_dx / (I * w * densityPhy)
c1_R = c1 / R
function velA(x, y, z, t)
  result = c2 * math.exp(I*w*t) * ( 1 - math.cosh(y*c1_R) / math.cosh(c1) )
  return { result:real() / velMaxPhy, 0, 0 }
end

-- Wall Shear Stress
function wssA(x, y, z, t)
  result = -viscPhy*c1_R*c2 * math.exp(I*w*t) * (math.sinh(y*c1_R)/math.cosh(c1))
  return { 0, 0, 0, result:real(), 0, 0, }
end
