require "common"

sim_control = {
  time_control = {
    max = { iter = tmax },
    interval = { iter = tmax/10 }
  },
} -- sim_control


physics = { dt = dt, rho0 = densityPhy }

identify = {
  kind = kind,
  relaxation = relaxation,
  layout = layout,
}

source = { force = 'myforce', }

variable = {
  -- analytical solution
  { name='vel_an',  ncomponents=3, vartype = 'st_fun', st_fun = velA },
  { name='wss_an',  ncomponents=6, vartype = 'st_fun', st_fun = wssA },
  { name='inv_umax',ncomponents=3, vartype = 'st_fun', st_fun = {1.0/velMaxPhy,0,0} },
  -- normalized velocity = vel / umax
  { name='norm_vel',   ncomponents=3, vartype = 'operation',
    operation = {
      kind = 'multiplication',
      input_varname = { 'velocity_phy', 'inv_umax' },
    },
  },
  -- errors
  { name='error_v',   ncomponents=3, vartype = 'operation',
    operation = {
      kind = 'difference',
      input_varname = { 'velocity_phy', 'vel_an' },
    },
  },
  { name='error_w',   ncomponents=6, vartype = 'operation',
    operation = {
      kind = 'difference',
      input_varname = { 'shear_stress_phy', 'wss_an' },
    },
  },
  {
    name = 'myforce',
    ncomponents = 3,
    vartype = 'st_fun',
    st_fun = {
      predefined = 'combined',
      -- temporal  = forceFun,
      temporal = { predefined = 'cos', },
      spatial = {dp_dx * dx * dx * dx,0.0,0.0}
    }, -- st_fun
  },
}

racking = {
  { -- track whole domain
    label = 'global',
    variable = {
      'velocity_phy',
      -- 'wss_phy',
      'pressure_phy',
      -- 'vel_an',
      -- 'wss_an',
    },
    shape = { kind = 'global', },
    time_control = {
      min = { iter = 300 },
      max = { iter = tmax },
      interval = { iter = 1000 }, },
    folder = './output/',
    output = { format = 'vtk', },
  },
} -- tracking

tracking = {
  { -- spatial profile across channel in the middle between inlet & outlet
    label = 'middle_spatial',
    variable = {
      'velocity_phy', -- 4 5 6
      'vel_an',       -- 7 8 9
      'shear_stress_phy', -- 10 11 12 13 14 15
      'wss_an', -- 16 17 18 19 20 21
      'wss_phy', -- 22
      'pressure_phy',  -- 23
    },
    shape = {
      kind = 'canoND',
      object = {
        origin = { 0.0, -height/2, dx/2},
        vec = { 0.0, height, 0.0},
        segments = {200},
      }
    }, -- shape
    time_control = {
      min = { iter = tmax - TLB*7/8 },
      max = { iter = tmax },
      interval = { iter = TLB/8   },
    },
    folder = './tracking/',
    output = { format = 'asciiSpatial', },
  },

  { -- temporal
    label = 'temporal',
    variable = { 'norm_vel', 'vel_an', },
    shape = {
      kind = 'canoND',
      object = { origin = { 0.0, 0, dx/2}, }
    }, -- shape
    time_control = {
      min = { iter = tmax - TLB },
      max = { iter = tmax },
      interval = { iter = TLB / 36 },
    },
    folder = './tracking/',
    output = { format = 'ascii', },
  },

  { -- total density
    label = 'total_density',
    variable = { 'density' },
    shape = { kind = 'global', },
    time_control = {
      min = { iter = tmax },
      max = { iter = tmax },
      interval = { iter = TLB / 36 },
    },
    folder = './tracking/',
    output = { format = 'ascii', },
    reduction = {'sum'},
  },

  { -- l2norm
    label = 'l2norm',
    variable = {
      'error_v', -- 2 3 4
      'vel_an',  -- 5 6 7
      'error_w',  -- 8 9 10 11 12 13
      'wss_an',   -- 14 15 16 17 18 19
    },
    shape = {
      kind = 'canoND',
      object = {
        origin = { 0.0, -height/2, dx/2},
        vec = { 0.0, height, 0.0},
        segments = {100}
      },
    }, -- shape
    time_control = {
      min = { iter = tmax - TLB*7/8 },
      max = { iter = tmax },
      interval = { iter = TLB/8 },
    },
    reduction = {'l2norm', 'l2norm', 'l2norm', 'l2norm'},
    folder = './tracking/',
    output = { format = 'ascii', },
  },

} -- tracking

fluid = { omega = omega }

initial_condition = {
  pressure = p0Phy,
  velocityX = 0, velocityY = 0.0, velocityZ = 0.0,
  Sxx = 0, Syy = 0, Szz = 0, Sxy = 0, Syz = 0, Sxz = 0,
}

boundary_condition = {
  { label = 'top',    kind = 'wall', },
  { label = 'bottom', kind = 'wall', },
} -- BC
