-- maximum refinement level
level = 8
-- all units are in physical units
-- length (m)
l_ref = 0.04
length = l_ref*2.0
-- molecular weights(kg/m^3)
m1_p = 2.0e-3
m2_p = 28.0e-3
m3_p = 44.0e-3

-- reference values
-- molecular weight
m_ref = 1.0e-3
-- mesh size (m)
dx = length/(2^level)
-- time size (s)
dt = 1.0e-3
-- reference diffusivity
d_ref = dx*dx/dt

-- dimensionless parameters
m1 = m1_p/m_ref
m2 = m2_p/m_ref
m3 = m3_p/m_ref
m1_1 = 1.0
-- molecular weight ratio
-- according to asinari model, m_rsig = min_varsig(m_varsig)/m_sig
m_min = math.min(m1,m2,m3)
m_r1 = m_min/m1
m_r2 = m_min/m2
m_r3 = m_min/m3

b_11 = 0.5*10/((2/m1)^0.5)
b_22 = 0.5*10/((2/m2)^0.5)
b_33 = 0.5*10/((2/m3)^0.5)

-- lua function to initialize density
shift = 0.05
delta = 0.05
pi = math.pi
function species1Per( x, y, z ,t)
  return (shift+delta*(1.0+math.sin(2.0*pi*x/length)))*3.0/m_r1
end
function species2Per( x, y, z ,t)
  return (shift+delta*(1.0+math.cos(2.0*pi*x/length)))*3.0/m_r2
end
function species3Per( x, y, z ,t)
  return ( 1.0 - (2.0*(shift+delta)+delta*(math.sin(2.0*pi*x/length)+math.cos(2.0*pi*x/length))) )
          *3.0/m_r3
end


function species1Noflux( x, y, z,t )
  return (0.5*(0.5+0.5*(math.tanh(10.0*(x/length-0.5)))))*3.0/m_r1
end

function species2Noflux( x, y, z ,t)
  return 0.5*3.0/m_r2
end

function species3Noflux( x, y, z ,t)
  return (1.0-(0.5*(0.5+0.5*(math.tanh(10.0*(x/length-0.5))))+0.5))*3.0/m_r3
end

-- diffusivity coeff
d_11 = 1.0/b_11
d_22 = 1.0/b_22
d_33 = 1.0/b_33

d_12 = 0.833e-4/d_ref
d_21 = d_12
d_13 = 0.68e-4/d_ref
d_31 = d_13
d_23 = 0.168e-4/d_ref  
d_32 = d_23

diff_coeff1 = { d_11, d_12, d_13 }
diff_coeff2 = { d_21, d_22, d_23 }
diff_coeff3 = { d_31, d_32, d_33 }


-- boundary condition for each field              
spc_bc = {
   { kind = 'spc_outlet_zero_prsgrd',
     label = 'east'},
   { kind = 'inlet_eq',
     label = 'west',
     velocityX=0.001,velocityY=0.0, velocityZ=0.0,
     density = 1.0},
   { kind = 'wall',
     label = 'north'},
   { kind = 'wall',
     label = 'south'}}
fluid_bc = {
   { kind = 'outlet_zero_prsgrd',
     label = 'east'},
   { kind = 'inlet_eq',
     label = 'west',
     velocityX=0.001,velocityY=0.0, velocityZ=0.0,
     density = 1.0},
   { kind = 'wall',
     label = 'north'},
   { kind = 'wall',
     label = 'south'}}

-- initial condition
ic = { 
   density = 1.0,
   velocityX = 0.0,
   velocityY = 0.0,
   velocityZ = 0.0}

tmax           =  10000     -- total iteration number
omega = 1.7
nu_L = (1.0/omega - 0.5)/3.0
inv_nuL = 1.0/nu_L
-- scheme for single fluid 
scheme_fluid = {
  identify={layout='d2q9'},
  fluid = { omega = omega, rho0 = 1.0 }
 ,initial_condition = ic 
 ,boundary_condition = fluid_bc
,tracking = {
  {
   label = 'velocity', 
   variable = {'velocity'},
   folder = 'tracking/',
   shape = {kind = 'canoND', object= {origin={0.0,-l_ref/2.0,0.0},
                                      vec={0.0,l_ref,0.0},
                                      segments = 1000 }
           },
   format = 'asciiSpatial',
   time = {min = 0, max = tmax, interval = tmax/10}, 
  },
  {label = 'point',
  variable = {'velocity'},
  folder = 'tracking/',
  shape = {kind = 'canoND', object= {origin={0.0,0.0,0.0}},
           },
   format = 'ascii',
   time = {min = 0, max = tmax, interval = tmax/100}, 
  }}
}  

-- scheme for mix
diff_coeff1_1 = { nu_L, nu_L, nu_L }
species_1 = { molweight = m1_1, diff_coeff = diff_coeff1_1  }
scheme_mix={
   identify = {
      label = 'mix',
      kind = 'multi-species_gas', 
--      relaxation = 'bgk', 
-- scheme layout
      layout = 'd3q19'
},
mixture = { rho0 = rho0_p, 
            omega_diff = 2.0,
            --kine_shear_viscosity = nu_p,
            omega_kine = 2.0,
            initial_condition = { pressure = 0.0}--TGV_kinematicPressure }
            },

  -- field which defines fluid or specie
  -- Single fluid simulation
  field = {{
      label = 'H2'
-- species properties
     ,species = species_1 
-- Initial condition
     ,initial_condition = ic
     ,boundary_condition = spc_bc
     }
   ,{
     label = 'N2'
    ,species =  species_1
    ,initial_condition = ic
    ,boundary_condition = spc_bc 
       }
   ,{
     label = 'CO2'
    ,species =  species_1
    ,initial_condition = ic
    ,boundary_condition = spc_bc 
    }
  },
tracking = {
  {
   label = 'velocity', 
   variable = {'H2_velocity','N2_velocity','CO2_velocity','velocity'},
   folder = 'tracking/',
   shape = {kind = 'canoND', object= {origin={0.0,-l_ref/2.0,0.0},
                                      vec={0.0,l_ref,0.0},
                                      segments = 1000 }
           },
   format = 'asciiSpatial',
   time_control = {min= {iter= 0}, max= {iter=tmax}, interval= {iter= tmax/10}},
  },
  {label = 'point',
  variable = {'H2_velocity'},
  folder = 'tracking/',
  shape = {kind = 'canoND', object= {origin={0.0,0.0,0.0}},
           },
   format = 'ascii',
   time_control = {min={iter = 0}, max= {iter= tmax}, interval= {iter=
     tmax/100}},
  }}
}
