-- Musubi configuration file for passive scalar verification.

require "common"

-- analytical solution depending only on x (equation in physical units)
function anaSol_x(x, y, z, t)
  -- calculte the physical time from the passed LB-time
  t_phy = t*dt
  phi = math.exp(-D_phy*(2*math.pi/L_phy)^2*t_phy)*math.sin(2*math.pi/L_phy*x) + 1.000001
--  print('anaSol: ', phi)
--  print('for ')
--  print('x: ', x)
--  print('t: ', t)
--  print('--------------------')
  return phi
end

-- initial condition depending only on x (equation in physical units)
function iniCond_x(x, y, z, t)
  phi = (math.sin(2*math.pi/L_phy*x) + 1.000001)/3.0
--  print('iniCond: ', phi)
--  print('iniCond2: ', phi*3.0)
--  print('for ')
--  print('x: ', x)
--  print('--------------------')
  return phi
end

-- Simulation name
simulation_name = 'diff_vali_x'
mesh = { predefined='cube', 
         origin = {0.,0.,0.}, 
         length = L_phy, 
         refinementLevel = ref_level }
printRuntimeInfo = true
-- Debug options
--debug = { debugMode = true,  -- activate global debug modus
--          debugFiles = true, -- open the debugFiles for each process dbgOut0000**.out
--          dumpDependencies = true -- write the dependencies between levels to disk
--          }

-- Interpolation method
--interpolation_method = 'average'                   

-- Time step settigs
tmax           = nIter     -- total iteration number
--tmax           = 2
time = {useIterations = true,
        min = 1, max = tmax, interval = checkInter}

scheme = {
  {
  -- simulation kind
  identify = { label = 'species', kind = 'passive_scalar', 
               relaxation = 'bgk_noFluid', layout = 'flekkoy' },

  -- define the underlying velocity to be 0 for pure diffusion verification
  depend = { variable={'zero_vel'} },

  -- add extra variables
  variable = { { name = 'anaSolX', 
                 ncomponents=1, 
                 vartype='st_fun', 
                 st_fun = anaSol_x},
               { name = 'diff_spc1_ana', 
                 ncomponents = 1, 
                 vartype='operation',
                 operation = {
                      kind = 'difference',
                      input_varname={'spc1_density', 'anaSolX'}
                    }
               },
               { name = 'zero_vel',
                 ncomponents = 3,
                 vartype = 'st_fun',
                 st_fun = {0.0,0.0,0.0}
               }

    },
  
  tracking = {
--               { label = 'spc1_harv', 
--                 variable = {'spc1_density'},
--                 folder = track_dir,
--                 shape = {kind = 'all'},
--                 format = 'harvester',
--                 time = {min = 0, max = tmax, interval = checkInter}},
               { label = 'error2_3', 
                 variable = {'diff_spc1_ana'
                            },
                 folder = track_dir,
                 shape = { kind = 'canoND', object = { origin = { 2.0*L_phy/3.0, L_phy/2.0, L_phy/2.0 }}
                         },
                 format = 'ascii',
                 time = {min = 0, max = tmax, interval = 10}},
               { label = 'error1_3', 
                 variable = {'diff_spc1_ana'
                            },
                 folder = track_dir,
                 shape = { kind = 'canoND', object = { origin = { L_phy/3.0, L_phy/2.0, L_phy/2.0 }}
                         },
                 format = 'ascii',
                 time = {min = 0, max = tmax, interval = 10}},

               { label = 'anaSol1_3', 
                 variable = {'anaSolX', 'spc1_density'},
--                 variable = {
--                              { name = 'difference', ncomponents = 1, dep={'spc1_density', 'anaSolX'}}
--                            },
                 folder = track_dir,
                 shape = { kind = 'canoND', object = { origin = { L_phy/3.0, L_phy/2.0, L_phy/2.0 }}
                         },
                 format = 'ascii',
                 time = {min = 0, max = tmax, interval = 10}},
               { label = 'anaSol2_3', 
                 variable = {'anaSolX', 'spc1_density'},
--                 variable = {
--                              { name = 'difference', ncomponents = 1, dep={'spc1_density', 'anaSolX'}}
--                            },
                 folder = track_dir,
                 shape = { kind = 'canoND', object = { origin = { 2.0*L_phy/3.0, L_phy/2.0, L_phy/2.0 }}
                         },
                 format = 'ascii',
                 time = {min = 0, max = tmax, interval = 10}},

--               { label = 'error', 
--                 variable = {'diff_spc1_ana'
--                            },
--                 folder = track_dir,
--                 shape = { kind = 'canoND', object = { origin = { 0.0, L_phy/2.0, L_phy/2.0 },
--                                                       vec = { L_phy, 0.0, 0.0 },
--                                                       segments={150}
--                                                     }
--                         },
--                 format = 'asciiSpatial',
--                 time = {min = 0, max = tmax, interval = error_check_inter}},
--
--               { label = 'spc1_anaSol', 
--                 variable = {'spc1_density','anaSolX'},
--                 folder = track_dir,
--                 shape = { kind = 'canoND', object = { origin = { 0.0, L_phy/2.0, L_phy/2.0 },
--                                                       vec = { L_phy, 0.0, 0.0 },
--                                                       segments={150}
--                                                     }
--                         },
--                 format = 'asciiSpatial',
--                 time = {min = 0, max = tmax, interval = error_check_inter}}  --error_check_inter}}
              },
              
  field = {
    -- field 1 = species 1
    { label = 'spc1',
      species = { 
                  diff_coeff = {D}
      },
      initial_condition = { pressure = iniCond_x,
                            velocityX = 0.0,
                            velocityY = 0.0,
                            velocityZ = 0.0 },
    }
  -- close the field table
  }
 -- close the current scheme
 }
 -- close the scheme table
}
