! See copyright notice in the COPYRIGHT file.
!> This UTEST is to test variable system.
!! load variables and access state and derive quantities from
!! c pointer methoddata
program tem_spacetime_fun_test
  use, intrinsic :: iso_c_binding, only: C_NEW_LINE, c_ptr, c_loc, c_f_pointer

  use env_module,               only: rk, solSpecLen
  use tem_bc_prop_module,       only: tem_bc_prop_type
  use tem_general_module,       only: tem_general_type
  use treelmesh_module,         only: treelmesh_type
  use tem_utestEnv_module,      only: load_env
  use tem_tools_module,         only: upper_to_lower
  use tem_spacetime_fun_module, only: tem_spacetime_fun_type,             &
    &                                 tem_load_spacetime,                 &
    &                                 tem_st_fun_listElem_type,           &
    &                                 tem_st_fun_linkedList_type, append, &
    &                                 tem_spacetime_for
  use tem_logging_module,       only: tem_logging_init, logUnit

  use aotus_module,             only: open_config_chunk, close_config, &
    &                                 flu_state
  use aot_table_module,         only: aot_table_open, aot_table_close, &
    &                                 aot_table_length, aot_get_val

  implicit none

  character, parameter :: nl = C_NEW_LINE

  character(len=solSpecLen), parameter :: stfun_Conf =                         &
    &   'function luafun_vector(x,y,z,t)' // nl                                &
    & //'  return {x,y,z}' // nl                                               &
    & //'end' // nl                                                            &
    & //'function luafun_scalar(x,y,z,t)' // nl                                &
    & //'  return x' // nl                                                     &
    & //'end' // nl                                                            &
    & //'shape = {kind = "canoND", '// nl                                      &
    & //'         object = { '// nl                                            &
    & //'           origin = {0.0,0.5,0.5},' //nl                              &
    & //'           vec = {1.0,0.0,0.0}}}' // nl                               &
    & //'scalar_fun = luafun_scalar' // nl                                     &
    & //'scalar_const = 1.0' // nl                                             &
    & //'vector_fun = luafun_vector' // nl                                     &
    & //'vector_const = {1.0,2.0,3.0}' // nl                                   &
    & //'vector_const_multitab = {{1.0,2.0,3.0},{4.0,5.0,6.0}}' // nl          &
    & //'scalar_fun_shapeall = { fun = luafun_scalar }' // nl                  &
    & //'scalar_const_shapeall = { const = scalar_const }' // nl               &
    & //'predefined_shapeall = { predefined = "combined", ' // nl              &
    & //'                     temporal = 1.0, '// nl                           &
    & //'                     spatial = 1.0} ' // nl                           &
    & //'scalar_fun_shape = { fun = luafun_scalar, shape = shape }' // nl      &
    & //'scalar_const_shape = { const = 1.0, shape = shape }' // nl            &
    & //'vector_fun_shape = { fun = luafun_vector, shape = shape }' // nl      &
    & //'vector_const_shape = { const = {1.0,2.0,3.0}, shape = shape }' // nl  &
    & //'predefined_shape = { predefined = "combined", ' // nl                 &
    & //'                     temporal = 1.0, '// nl                           &
    & //'                     spatial = scalar_fun, ' // nl                    &
    & //'                     shape = shape }' // nl                           &
    & //'predefined_vec_shape = { predefined = "combined", ' // nl             &
    & //'                     temporal = 1.0, '// nl                           &
    & //'                     spatial = {1.0,2.0,3.0},' // nl                  &
    & //'                     shape = shape }' // nl                           &
    & //'st_fun_singleTab  = { scalar_fun } '// nl                             &
    & //'st_fun_singleTab_shape  = { fun=scalar_fun, shape=shape } '// nl      &
    & //'st_fun_multiTab  = { { fun=scalar_fun }} '// nl                       &
    & //'st_fun_const  = { scalar_const , '// nl                               &
    & //'            scalar_const*2 , '// nl                                   &
    & //'            scalar_const*3 } ' // nl                                  &
    & //'st_fun_vec_const  = { vector_const , '// nl                           &
    & //'            vector_const , '// nl                                     &
    & //'            vector_const } ' // nl                                    &
    & //'st_fun  = { scalar_fun , '// nl                                       &
    & //'            scalar_fun , '// nl                                       &
    & //'            predefined_shape } ' // nl

  type solver_type
    integer :: nComps
    integer :: nDofs
    real(kind=rk), allocatable :: state(:)
    type(treelmesh_type) :: tree
    type(tem_bc_prop_type) :: boundary
    type(tem_general_type) :: general
  end type solver_type

  type(flu_state) :: conf
  type(tem_st_fun_linkedList_type) :: st_fun
  type(solver_type), target :: solver
  integer :: errCode(10)
  type(tem_spacetime_fun_type) :: density
  type(tem_spacetime_fun_type) :: velocity
  type(tem_spacetime_fun_type), allocatable :: sourceFun(:)

  write(*,*) 'Hello from tem_varSys_test'
  ! load utest mesh
  call load_env( tree     = solver%tree,     &
    &            boundary = solver%boundary, &
    &            general  = solver%general   )

  call tem_logging_init( level = 10, rank = 0 )

  write(*,*) 'nElems ', solver%tree%nElems
  errCode = 0

  call open_config_chunk(L=conf, chunk=trim(stfun_conf))

  call tem_load_spacetime( me   = density,     &
    &                      conf = conf,        &
    &                      errCode = errCode(1),     &
    &                      key  = 'scalar_fun' )
  call append( st_fun, density )

  call tem_load_spacetime( me   = density,       &
    &                      conf = conf,          &
    &                      errCode = errCode(2),     &
    &                      key  = 'scalar_const' )
  call append( st_fun, density )

  call tem_load_spacetime( me    = velocity,    &
    &                      conf  = conf,        &
    &                      nComp = 3,           &
    &                      errCode = errCode(3),     &
    &                      key   = 'vector_fun' )
  call append( st_fun, velocity )

  call tem_load_spacetime( me    = velocity,      &
    &                      conf  = conf,          &
    &                      nComp = 3,             &
    &                      errCode = errCode(4),     &
    &                      key   = 'vector_const' )
  call append( st_fun, velocity )

  call tem_load_spacetime( me    = sourceFun,     &
    &                      conf  = conf,          &
    &                      nComp = 3,             &
    &                      errCode = errCode(5),     &
    &                      key   = 'vector_const_multitab' )
  call append( st_fun, velocity )
!
!  call tem_load_spacetime( me    = density,              &
!    &                      conf  = conf,                 &
!    &                      errCode = errCode,     &
!    &                      key   = 'scalar_fun_shapeall' )
!  call append( st_fun, density )
!
!  call tem_load_spacetime( me    = density,                &
!    &                      conf  = conf,                   &
!    &                      errCode = errCode,     &
!    &                      key   = 'scalar_const_shapeall' )
!  call append( st_fun, density )
!
  call tem_load_spacetime( me    = density,              &
    &                      conf  = conf,                 &
    &                      errCode = errCode(6),     &
    &                      key   = 'predefined_shapeall' )
  call append( st_fun, density )
!
!  call tem_load_spacetime( me    = density,              &
!    &                      conf  = conf,                 &
!    &                      errCode = errCode,     &
!    &                      key   = 'scalar_fun_shape' )
!  write(*,*) 'shapekind ', density%geom(:)%kind
!  call append( st_fun, density )
!
!  call tem_load_spacetime( me    = density,              &
!    &                      conf  = conf,                 &
!    &                      key   = 'scalar_const_shape' )
!  !write(*,*) 'shapekind ', density%geom(:)%kind
!  call append( st_fun, density )
!
!  call tem_load_spacetime( me    = velocity,          &
!    &                      conf  = conf,              &
!    &                      nComp = 3,                 &
!    &                      errCode = errCode,     &
!    &                      key   = 'vector_fun_shape' )
!  call append( st_fun, velocity )
!
!  call tem_load_spacetime( me    = velocity,            &
!    &                      conf  = conf,                &
!    &                      nComp = 3,                   &
!    &                      key   = 'vector_const_shape' )
!  call append( st_fun, velocity )
!
!  call tem_load_spacetime( me    = density,           &
!    &                      conf  = conf,              &
!    &                      key   = 'predefined_shape' )
!  call append( st_fun, density )
!
!  call tem_load_spacetime( me    = velocity,          &
!    &                      conf  = conf,              &
!    &                      ncomp = 3,                 &
!    &                      errCode = errCode,     &
!    &                      key   = 'predefined_vec_shape' )
!  call append( st_fun, velocity )


!  call tem_load_spacetime( me    = sourceFun,         &
!    &                      conf  = conf,              &
!    &                      errCode = errCode,     &
!    &                      key   = 'scalar_fun' )
!  call append( st_fun, sourceFun )
!
!  call tem_load_spacetime( me    = sourceFun,         &
!    &                      conf  = conf,              &
!    &                      nComp = 3,                 &
!    &                      errCode = errCode,     &
!    &                      key   = 'vector_const' )
!  call append( st_fun, sourceFun )
!
!  call tem_load_spacetime( me    = sourceFun,         &
!    &                      conf  = conf,              &
!    &                      errCode = errCode,     &
!    &                      key   = 'st_fun_singleTab' )
!  call append( st_fun, sourceFun )
!
  call tem_load_spacetime( me    = sourceFun,         &
    &                      conf  = conf,              &
    &                      errCode = errCode(7),     &
    &                      key   = 'st_fun_singleTab_shape' )
  call append( st_fun, sourceFun )

  call tem_load_spacetime( me    = sourceFun,         &
    &                      conf  = conf,              &
    &                      errCode = errCode(8),     &
    &                      key   = 'st_fun_multiTab' )
  call append( st_fun, sourceFun )
!
!  call tem_load_spacetime( me    = sourceFun,         &
!    &                      conf  = conf,              &
!    &                      errCode = errCode,     &
!    &                      errCode = errCode,     &
!    &                      key   = 'st_fun_const' )
!  call append( st_fun, sourceFun )
!
  call tem_load_spacetime( me    = sourceFun,         &
    &                      conf  = conf,              &
    &                      nComp = 3,                 &
    &                      errCode = errCode(9),     &
    &                      key   = 'st_fun_vec_const' )
  call append( st_fun, sourceFun )

  call tem_load_spacetime( me    = sourceFun,         &
    &                      conf  = conf,              &
    &                      errCode = errCode(10),     &
    &                      key   = 'st_fun' )
  call append( st_fun, sourceFun )

  if ( any(errCode == -1) )  then
    write(logUnit(1),*) 'Error: Failed loading spacetime function calls.'
    write(logUnit(1),*) 'Failed call has errcode -1'
    write(logUnit(1),*) 'Errcode ', errCode
  else
    write(*,*) 'PASSED'
  end if
  call close_config(L=conf)

end program tem_spacetime_fun_test

