! See copyright notice in the COPYRIGHT file.
!> This unit test tests the different evaluation types for user defined
!! variables.
program tem_variable_last_test

  use, intrinsic :: iso_c_binding, only: C_NEW_LINE, c_ptr, c_loc, c_f_pointer

  use env_module,               only: eps, rk, solSpecLen

  use aotus_module,             only: open_config_chunk, &
    &                                 close_config,      &
    &                                 flu_state
  use aot_table_module,         only: aot_table_open,   &
    &                                 aot_table_close,  &
    &                                 aot_table_length, &
    &                                 aot_get_val

  use tem_logging_module,       only: tem_logging_init
  use treelmesh_module,         only: treelmesh_type
  use tem_bc_prop_module,       only: tem_bc_prop_type
  use tem_general_module,       only: tem_general_type
  use tem_variable_module,      only: tem_variable_type, &
    &                                 tem_variable_load
  use tem_spacetime_fun_module, only: tem_st_fun_linkedList_type
  use tem_derived_module,       only: tem_varSys_append_luaVar
  use tem_spacetime_fun_module, only: tem_create_subTree_of_st_funList
  use tem_varSys_module,        only: tem_varSys_init,            &
    &                                 tem_varSys_type,            &
    &                                 tem_varSys_op_type,         &
    &                                 tem_varSys_append_stateVar, &
    &                                 tem_varSys_append_derVar,   &
    &                                 tem_varSys_proc_point,      &
    &                                 tem_varSys_proc_element
  use tem_dyn_array_module,     only: PositionOfVal

  use tem_utestEnv_module,      only: load_env

  implicit none

  character, parameter :: nl = C_NEW_LINE

  character(len=solSpecLen), parameter :: sysConf =                            &
    &   'variable = {' // nl                                                   &
    & //'               {' // nl                                               &
    & //'                 name = "3",' // nl                                   &
    & //'                 ncomponents = 1, '// nl                              &
    & //'                 vartype = "st_fun",'// nl                            &
    & //'                 st_fun = { ' // nl                                   &
    & //'                   { const = {1} },' // nl                            &
    & //'                   { const = {2} }' // nl                             &
    & //'                 }' // nl                                             &
    & //'               }, ' // nl                                             &
    & //'               {' // nl                                               &
    & //'                 name = "explicitly_3",' // nl                        &
    & //'                 ncomponents = 1,' // nl                              &
    & //'                 vartype = "st_fun",' // nl                           &
    & //'                 evaltype = "add",' // nl                             &
    & //'                 st_fun = {' // nl                                    &
    & //'                   { const = {1} },' // nl                            &
    & //'                   { const = {2} }' // nl                             &
    & //'                 }' // nl                                             &
    & //'               }, ' // nl                                             &
    & //'               {' // nl                                               &
    & //'                 name = "just_2",' // nl                              &
    & //'                 ncomponents = 1,' // nl                              &
    & //'                 vartype = "st_fun",' // nl                           &
    & //'                 evaltype = "first",' // nl                           &
    & //'                 st_fun = {' // nl                                    &
    & //'                   { const = {1} },' // nl                            &
    & //'                   { const = {2} }' // nl                             &
    & //'                  }' // nl                                            &
    & //'               }' // nl                                               &
    & //' }' // nl

  type solver_type
    integer :: nDofs
    real(kind=rk), allocatable :: state(:)
    type(treelmesh_type) :: tree
    type(tem_bc_prop_type) :: boundary
    type(tem_general_type) :: general
  end type solver_type

  integer :: nComponents, nDofs, nElemsToTrack, pos
  type(solver_type), target :: solver
  type(tem_varSys_type) :: varSys
  type(tem_st_fun_linkedList_type) :: st_funList
  type(tem_variable_type), allocatable :: newVar(:)
  real(kind=rk), allocatable :: res(:)
  integer, allocatable :: vError(:)

  write(*,*) 'Hello from tem_variable_first_test'
  ! load utest mesh
  call load_env( tree     = solver%tree,     &
    &            boundary = solver%boundary, &
    &            general  = solver%general   )

  call tem_logging_init( level = 10, rank = 0 )
  write(*,*) 'nElems ', solver%tree%nElems

  allocate(solver%general%solver%conf(1))
  call open_config_chunk(L=solver%general%solver%conf(1), chunk=trim(sysConf))

  call tem_variable_load( me     = newVar,                        &
    &                     conf   = solver%general%solver%conf(1), &
    &                     key    = 'variable',                    &
    &                     vError = vError                         )
  ! for the sake of the address sanitizer
  deallocate(vError)
  call close_config(L=solver%general%solver%conf(1))

  nElemsToTrack = 1
  nComponents = 1
  nDofs = 1

  ! initialize variable system
  write(*,*) 'calling varsys init'
  call tem_varSys_init(me = varSys, systemName = 'utest')

  call tem_varSys_append_luaVar( luaVar     = newVar,    &
    &                            varSys     = varSys,    &
    &                            st_funList = st_funList )

  call tem_create_subTree_of_st_funList( &
    & me      = st_funList,              &
    & tree    = solver%tree,             &
    & bc_prop = solver%boundary          )

  allocate(res(nElemsToTrack*nComponents*nDofs))
  pos = positionOfVal( varSys%varname, "3" )
  call varSys%method%val(pos)%get_element(     &
    & varSys  = varSys,                        &
    & elemPos = (/ 1 /),                       &
    & time    = solver%general%simControl%now, &
    & tree    = solver%tree,                   &
    & nElems  = nElemsToTrack,                 &
    & nDofs   = nDofs,                         &
    & res     = res                            )
  write(*,*) res
  if( abs(res(1) - 3) > eps ) then
    write(*,*) 'FAILED: Variable 3 returned wrong value.'
    stop
  endif

  pos = positionOfVal( varSys%varname, "explicitly_3" )
  call varSys%method%val(pos)%get_element(     &
    & varSys  = varSys,                        &
    & elemPos = (/ 1 /),                       &
    & time    = solver%general%simControl%now, &
    & tree    = solver%tree,                   &
    & nElems  = nElemsToTrack,                 &
    & nDofs   = nDofs,                         &
    & res     = res                            )
  write(*,*) res
  if( abs(res(1) - 3) > eps ) then
    write(*,*) 'FAILED: Variable 3 returned wrong value.'
    stop
  endif

  pos = positionOfVal( varSys%varname, "just_2" )
  call varSys%method%val(pos)%get_element(     &
    & varSys  = varSys,                        &
    & elemPos = (/ 1 /),                       &
    & time    = solver%general%simControl%now, &
    & tree    = solver%tree,                   &
    & nElems  = nElemsToTrack,                 &
    & nDofs   = nDofs,                         &
    & res     = res                            )
  write(*,*) res
  if( abs(res(1) - 1) > eps ) then
    write(*,*) 'FAILED: Variable 3 returned wrong value.'
    stop
  endif

  ! for the sake of the address sanitizer
  deallocate(res)

  write(*,*) 'PASSED'

end program tem_variable_last_test
